==> vacuum-1.0.1-source.tar.gz: vacuum-1.0.1/src/translations/pl_PL/xmppstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL" sourcelanguage="en">
<context>
    <name>XmppStream</name>
    <message>
        <source>Wrong XMPP stream negotiation response</source>
        <translation>Nieprawidłowa odpowiedź podczas negocjacji połączenia XMPP</translation>
    </message>
    <message>
        <source>Password request</source>
        <translation>Żądanie hasła</translation>
    </message>
    <message>
        <source>Enter password for &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Wpisz hasło dla &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Connection not specified</source>
        <translation>Połączenie nie zostało zdefiniowane</translation>
    </message>
    <message>
        <source>XMPP connection timed out</source>
        <translation>Został przekroczony czas nawiązywania połączenia XMPP</translation>
    </message>
</context>
<context>
    <name>XmppStreams</name>
    <message>
        <source>XMPP Streams Manager</source>
        <translation>Menedżer strumieni XMPP</translation>
    </message>
    <message>
        <source>Allows other modules to create XMPP streams and get access to them</source>
        <translation>Pozwala innym modułom na tworzenie i dostęp do strumieni XMPP</translation>
    </message>
    <message>
        <source>Bad Request Format</source>
        <translation>Zły format polecenia</translation>
    </message>
    <message>
        <source>Bad Namespace Prefix</source>
        <translation>Zły prefiks przestrzeni nazw</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Konflikt</translation>
    </message>
    <message>
        <source>Connection timeout</source>
        <translation>Przekroczono limit czasu połączenia</translation>
    </message>
    <message>
        <source>Host Gone</source>
        <translation>Host niedostępny</translation>
    </message>
    <message>
        <source>Host Unknown</source>
        <translation>Nieznany host</translation>
    </message>
    <message>
        <source>Improper Addressing</source>
        <translation>Nieprawidłowe adresowanie</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Wewnętrzny błąd serwera</translation>
    </message>
    <message>
        <source>Invalid From</source>
        <translation>Nieprawidłowy nadawca</translation>
    </message>
    <message>
        <source>Invalid Id</source>
        <translation>Nieprawidłowy ID</translation>
    </message>
    <message>
        <source>Invalid Namespace</source>
        <translation>Nieprawidłowa przestrzeń nazw</translation>
    </message>
    <message>
        <source>Invalid XML</source>
        <translation>Nieprawidłowy XML</translation>
    </message>
    <message>
        <source>Not Authorized</source>
        <translation>Nie autoryzowany</translation>
    </message>
    <message>
        <source>Policy Violation</source>
        <translation>Naruszenie reguł</translation>
    </message>
    <message>
        <source>Remote Connection Failed</source>
        <translation>Zdalne połączenie nie powiodło się</translation>
    </message>
    <message>
        <source>Resource Constraint</source>
        <translation>Ograniczenie zasobów</translation>
    </message>
    <message>
        <source>Restricted XML</source>
        <translation>Zabronione XML</translation>
    </message>
    <message>
        <source>See Other Host</source>
        <translation>Zobacz inny host</translation>
    </message>
    <message>
        <source>System Shutdown</source>
        <translation>Wyłączenie systemu</translation>
    </message>
    <message>
        <source>Undefined Condition</source>
        <translation>Niezdefiniowany warunek</translation>
    </message>
    <message>
        <source>Unsupported Encoding</source>
        <translation>Nieobsługiwane kodowanie</translation>
    </message>
    <message>
        <source>Unsupported Stanza Type</source>
        <translation>Nieobsługiwany format bloku XML</translation>
    </message>
    <message>
        <source>Unsupported Version</source>
        <translation>Nieobsługiwana wersja</translation>
    </message>
    <message>
        <source>XML Not Well Formed</source>
        <translation>Nieprawidłowo sformatowany XML</translation>
    </message>
</context>
</TS>

==> vacuum-1.0.2-source.tar.gz: vacuum-1.0.2/src/translations/pl_PL/xmppstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL" sourcelanguage="en">
<context>
    <name>XmppStream</name>
    <message>
        <source>Password request</source>
        <translation>Żądanie hasła</translation>
    </message>
    <message>
        <source>Enter password for &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Wpisz hasło dla &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Connection not specified</source>
        <translation>Połączenie nie zostało zdefiniowane</translation>
    </message>
    <message>
        <source>XMPP connection timed out</source>
        <translation>Został przekroczony czas nawiązywania połączenia XMPP</translation>
    </message>
    <message>
        <source>Failed to start connection</source>
        <translation>Nie można uruchomić połączenia</translation>
    </message>
</context>
<context>
    <name>XmppStreams</name>
    <message>
        <source>XMPP Streams Manager</source>
        <translation>Menedżer strumieni XMPP</translation>
    </message>
    <message>
        <source>Allows other modules to create XMPP streams and get access to them</source>
        <translation>Pozwala innym modułom na tworzenie i dostęp do strumieni XMPP</translation>
    </message>
    <message>
        <source>Bad Request Format</source>
        <translation>Zły format polecenia</translation>
    </message>
    <message>
        <source>Bad Namespace Prefix</source>
        <translation>Zły prefiks przestrzeni nazw</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Konflikt</translation>
    </message>
    <message>
        <source>Connection timeout</source>
        <translation>Przekroczono limit czasu połączenia</translation>
    </message>
    <message>
        <source>Host Gone</source>
        <translation>Host niedostępny</translation>
    </message>
    <message>
        <source>Host Unknown</source>
        <translation>Nieznany host</translation>
    </message>
    <message>
        <source>Improper Addressing</source>
        <translation>Nieprawidłowe adresowanie</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Wewnętrzny błąd serwera</translation>
    </message>
    <message>
        <source>Invalid From</source>
        <translation>Nieprawidłowy nadawca</translation>
    </message>
    <message>
        <source>Invalid Id</source>
        <translation>Nieprawidłowy ID</translation>
    </message>
    <message>
        <source>Invalid Namespace</source>
        <translation>Nieprawidłowa przestrzeń nazw</translation>
    </message>
    <message>
        <source>Invalid XML</source>
        <translation>Nieprawidłowy XML</translation>
    </message>
    <message>
        <source>Not Authorized</source>
        <translation>Nie autoryzowany</translation>
    </message>
    <message>
        <source>Policy Violation</source>
        <translation>Naruszenie reguł</translation>
    </message>
    <message>
        <source>Remote Connection Failed</source>
        <translation>Zdalne połączenie nie powiodło się</translation>
    </message>
    <message>
        <source>Resource Constraint</source>
        <translation>Ograniczenie zasobów</translation>
    </message>
    <message>
        <source>Restricted XML</source>
        <translation>Zabronione XML</translation>
    </message>
    <message>
        <source>See Other Host</source>
        <translation>Zobacz inny host</translation>
    </message>
    <message>
        <source>System Shutdown</source>
        <translation>Wyłączenie systemu</translation>
    </message>
    <message>
        <source>Undefined Condition</source>
        <translation>Niezdefiniowany warunek</translation>
    </message>
    <message>
        <source>Unsupported Encoding</source>
        <translation>Nieobsługiwane kodowanie</translation>
    </message>
    <message>
        <source>Unsupported Stanza Type</source>
        <translation>Nieobsługiwany format bloku XML</translation>
    </message>
    <message>
        <source>Unsupported Version</source>
        <translation>Nieobsługiwana wersja</translation>
    </message>
    <message>
        <source>XML Not Well Formed</source>
        <translation>Nieprawidłowo sformatowany XML</translation>
    </message>
</context>
</TS>
